==> MediaWikiLanguageExtensionBundle-2015.08.tar.bz2: extensions/cldr/CldrNames/CldrNamesOs.php <==
<?php

$languageNames = array(
	'ab' => 'абхазаг',
	'ady' => 'адыгейаг',
	'ae' => 'авестӕ',
	'af' => 'африкаанс',
	'ang' => 'рагон англисаг',
	'ar' => 'араббаг',
	'av' => 'авайраг',
	'az' => 'тӕтӕйраг',
	'ba' => 'башкираг',
	'bg' => 'болгайраг',
	'bs' => 'босниаг',
	'bua' => 'бурятаг',
	'ca' => 'каталайнаг',
	'ce' => 'цӕцӕйнаг',
	'cop' => 'коптаг',
	'cs' => 'чехаг',
	'cv' => 'чувашаг',
	'da' => 'даниаг',
	'de' => 'немыцаг',
	'de-at' => 'австралиаг немыцаг',
	'de-ch' => 'швйецариаг немыцаг',
	'egy' => 'рагон египтаг',
	'el' => 'бердзейнаг',
	'en' => 'англисаг',
	'en-au' => 'австралиаг англисаг',
	'en-ca' => 'канадӕйаг англисаг',
	'en-gb' => 'бритайнаг англисаг',
	'en-us' => 'америкаг англисаг',
	'eo' => 'есперанто',
	'es' => 'испайнаг',
	'es-419' => 'латинаг америкаг англисаг',
	'es-es' => 'европӕйаг англисаг',
	'et' => 'естойнаг',
	'eu' => 'баскаг',
	'fa' => 'персайнаг',
	'fi' => 'финнаг',
	'fil' => 'филиппинаг',
	'fj' => 'фиджи',
	'fo' => 'фарераг',
	'fr' => 'францаг',
	'fr-ca' => 'канадӕйаг францаг',
	'fr-ch' => 'швейцариаг францаг',
	'fro' => 'рагон францаг',
	'ga' => 'ирландиаг',
	'grc' => 'рагон бердзейнаг',
	'he' => 'уираг',
	'hr' => 'хорватаг',
	'hu' => 'венгериаг',
	'hy' => 'сомихаг',
	'inh' => 'мӕхъӕлон',
	'it' => 'италиаг',
	'ja' => 'япойнаг',
	'ka' => 'гуырдзиаг',
	'kbd' => 'кӕсгон',
	'krc' => 'бӕлхъӕрон',
	'ku' => 'курдаг',
	'kum' => 'хъуымыхъхъаг',
	'la' => 'латинаг',
	'lez' => 'лекъаг',
	'mk' => 'мӕчъидон',
	'os' => 'ирон',
	'pt' => 'португалиаг',
	'pt-br' => 'бразилиаг португалиаг',
	'pt-pt' => 'европӕйаг полтугалиаг',
	'rom' => 'цигайнаг',
	'ru' => 'уырыссаг',
	'und' => 'нӕзонгӕ ӕвзаг',
	'zh' => 'китайаг',
	'zh-hans' => 'ӕнцонгонд китайаг',
	'zh-hant' => 'традицион китайаг',
);

$currencyNames = array(
	'BRL' => 'Бразилиаг реал',
	'EUR' => 'Евро',
	'GBP' => 'Бритайнаг Фунт',
	'GEL' => 'Лар',
	'RUB' => 'Сом',
	'USD' => 'АИШ-ы Доллар',
	'XXX' => 'Нӕзонгӕ валютӕ',
);

$currencySymbols = array(
	'BRL' => 'R$',
	'EUR' => '€',
	'GBP' => '£',
	'USD' => '$',
);

$countryNames = array(
	'BR' => 'Бразили',
	'CN' => 'Китай',
	'DE' => 'Герман',
	'FR' => 'Франц',
	'GB' => 'Стыр Британи',
	'GE' => 'Гуырдзыстон',
	'IN' => 'Инди',
	'IT' => 'Итали',
	'JP' => 'Япон',
	'RU' => 'Уӕрӕсе',
	'US' => 'АИШ',
);

$timeUnits = array(
	'day-future-one' => '{0} боны фӕстӕ',
	'day-future-other' => '{0} боны фӕстӕ',
	'day-one' => '{0} бон',
	'day-other' => '{0} боны',
	'day-past-one' => '{0} бон раздӕр',
	'day-past-other' => '{0} боны размӕ',
	'hour-future-one' => '{0} сахаты фӕстӕ',
	'hour-future-other' => '{0} сахаты фӕстӕ',
	'hour-one' => '{0} сахат',
	'hour-other' => '{0} сахаты',
	'hour-past-one' => '{0} сахаты размӕ',
	'hour-past-other' => '{0} сахаты размӕ',
	'minute-one' => '{0} минут',
	'minute-other' => '{0} минуты',
	'month-one' => '{0} мӕй',
	'month-other' => '{0} мӕйы',
	'second-one' => '{0} секунд',
	'second-other' => '{0} секунды',
	'week-one' => '{0} къуыри',
	'week-other' => '{0} къуырийы',
	'year-one' => '{0} аз',
	'year-other' => '{0} азы',
);

==> MediaWikiLanguageExtensionBundle-2016.04.tar.bz2: extensions/cldr/CldrNames/CldrNamesOs.php <==
<?php

$languageNames = [
	'ab' => 'абхазаг',
	'ady' => 'адыгейаг',
	'ae' => 'авестӕ',
	'af' => 'африкаанс',
	'ang' => 'рагон англисаг',
	'ar' => 'араббаг',
	'av' => 'авайраг',
	'az' => 'тӕтӕйраг',
	'ba' => 'башкираг',
	'bg' => 'болгайраг',
	'bs' => 'босниаг',
	'bua' => 'бурятаг',
	'ca' => 'каталайнаг',
	'ce' => 'цӕцӕйнаг',
	'cop' => 'коптаг',
	'cs' => 'чехаг',
	'cv' => 'чувашаг',
	'da' => 'даниаг',
	'de' => 'немыцаг',
	'de-at' => 'австралиаг немыцаг',
	'de-ch' => 'швйецариаг немыцаг',
	'egy' => 'рагон египтаг',
	'el' => 'бердзейнаг',
	'en' => 'англисаг',
	'en-au' => 'австралиаг англисаг',
	'en-ca' => 'канадӕйаг англисаг',
	'en-gb' => 'бритайнаг англисаг',
	'en-us' => 'америкаг англисаг',
	'eo' => 'есперанто',
	'es' => 'испайнаг',
	'es-419' => 'латинаг америкаг англисаг',
	'es-es' => 'европӕйаг англисаг',
	'et' => 'естойнаг',
	'eu' => 'баскаг',
	'fa' => 'персайнаг',
	'fi' => 'финнаг',
	'fil' => 'филиппинаг',
	'fj' => 'фиджи',
	'fo' => 'фарераг',
	'fr' => 'францаг',
	'fr-ca' => 'канадӕйаг францаг',
	'fr-ch' => 'швейцариаг францаг',
	'fro' => 'рагон францаг',
	'ga' => 'ирландиаг',
	'grc' => 'рагон бердзейнаг',
	'he' => 'уираг',
	'hr' => 'хорватаг',
	'hu' => 'венгериаг',
	'hy' => 'сомихаг',
	'inh' => 'мӕхъӕлон',
	'it' => 'италиаг',
	'ja' => 'япойнаг',
	'ka' => 'гуырдзиаг',
	'kbd' => 'кӕсгон',
	'krc' => 'бӕлхъӕрон',
	'ku' => 'курдаг',
	'kum' => 'хъуымыхъхъаг',
	'la' => 'латинаг',
	'lez' => 'лекъаг',
	'mk' => 'мӕчъидон',
	'os' => 'ирон',
	'pt' => 'португалиаг',
	'pt-br' => 'бразилиаг португалиаг',
	'pt-pt' => 'европӕйаг полтугалиаг',
	'rom' => 'цигайнаг',
	'ru' => 'уырыссаг',
	'und' => 'нӕзонгӕ ӕвзаг',
	'zh' => 'китайаг',
	'zh-hans' => 'ӕнцонгонд китайаг',
	'zh-hant' => 'традицион китайаг',
];

$currencyNames = [
	'BRL' => 'Бразилиаг реал',
	'EUR' => 'Евро',
	'GBP' => 'Бритайнаг Фунт',
	'GEL' => 'Лар',
	'RUB' => 'Сом',
	'USD' => 'АИШ-ы Доллар',
	'XXX' => 'Нӕзонгӕ валютӕ',
];

$currencySymbols = [
	'BRL' => 'R$',
	'EUR' => '€',
	'GBP' => '£',
	'GEL' => '₾',
	'USD' => '$',
];

$countryNames = [
	'BR' => 'Бразили',
	'CN' => 'Китай',
	'DE' => 'Герман',
	'FR' => 'Франц',
	'GB' => 'Стыр Британи',
	'GE' => 'Гуырдзыстон',
	'IN' => 'Инди',
	'IT' => 'Итали',
	'JP' => 'Япон',
	'RU' => 'Уӕрӕсе',
	'US' => 'АИШ',
];

$timeUnits = [
	'day-future-one' => '{0} боны фӕстӕ',
	'day-future-other' => '{0} боны фӕстӕ',
	'day-one' => '{0} бон',
	'day-other' => '{0} боны',
	'day-past-one' => '{0} бон раздӕр',
	'day-past-other' => '{0} боны размӕ',
	'hour-future-one' => '{0} сахаты фӕстӕ',
	'hour-future-other' => '{0} сахаты фӕстӕ',
	'hour-one' => '{0} сахат',
	'hour-other' => '{0} сахаты',
	'hour-past-one' => '{0} сахаты размӕ',
	'hour-past-other' => '{0} сахаты размӕ',
	'minute-one' => '{0} минут',
	'minute-other' => '{0} минуты',
	'month-one' => '{0} мӕй',
	'month-other' => '{0} мӕйы',
	'second-one' => '{0} секунд',
	'second-other' => '{0} секунды',
	'week-one' => '{0} къуыри',
	'week-other' => '{0} къуырийы',
	'year-one' => '{0} аз',
	'year-other' => '{0} азы',
];
